
--------------------------------------------------------------------------------
--                pgr_version
--------------------------------------------------------------------------------
/* -- q1 */
SELECT version, library FROM pgr_full_version();
/* -- q2 */
